@@ -26,6 +26,7 @@ addTWPat = re.compile("(?<=<KNOWLEDGE_addTW>)[^<]*?(?=</KNOWLEDGE_addTW>)")
 currencyPat = re.compile("(?<=<KNOWLEDGE_currency>)[^<]*?(?=</KNOWLEDGE_currency>)")
 currencyGreedyPat = re.compile("(?<=[元金幣圜圓比布索鎊盾銖令朗郎]</ENTITY_noun><ENTITY_num>)[^<]*?(?=</ENTITY_num>)")
 currencyGreedyGapPat = re.compile("(?<=^<ENTITY_num>)[^<]*?(?=</ENTITY_num>)")
+chemicalPat = re.compile("(?<=<KNOWLEDGE_chemical>)[^<]*?(?=</KNOWLEDGE_chemical>)")
 wikiDataPat = re.compile("(?<=<KNOWLEDGE_wikiData>)[^<]*?(?=</KNOWLEDGE_wikiData>)")
 stripPat = re.compile("(?<=>).*?(?=<)")
 clausePat = re.compile("\<CLAUSE_.*?Q\>")
@@ -106,6 +107,25 @@ def getContentWordLIST(parseResultDICT, indexWithPOS=True):
         contentWordLIST = _segIndexConverter(parseResultDICT, contentWordLIST)
     return contentWordLIST
 
+def getChemicalLIST(parseResultDICT, indexWithPOS=True):
+    '''
+    取出斷詞結果中的 KNOWLEDGE_chemical。
+    每個句子內的 KNOWLEDGE_chemical 為一個 list.
+    '''
+    if "result_pos" in parseResultDICT:
+        pass
+    else:
+        return None
+    chemicalLIST = []
+    for p in parseResultDICT["result_pos"]:
+        if len(p) > 1:
+            chemicalLIST.append([(c.start(), c.end(), c.group(0)) for c in list(chemicalPat.finditer(p))])
+        else:
+            chemicalLIST.append([])
+    if not indexWithPOS:
+        chemicalLIST = _segIndexConverter(parseResultDICT, chemicalLIST)
+    return chemicalLIST
+
 def getVerbStemLIST(parseResultDICT, indexWithPOS=True):
     '''
     取出斷詞結果中的動詞 (verb)。此處指的是 ACTION_verb 標記的動詞詞彙。
@@ -121,7 +141,8 @@ def getVerbStemLIST(parseResultDICT, indexWithPOS=True):
         if len(p) > 1:
             if "VerbP" in p:
                 verbLIST.append([(v.start(), v.end(), v.group(0)) for v in list(verbPPat.finditer(p))])
-            verbLIST.append([(v.start(), v.end(), v.group(0)) for v in list(verbPat.finditer(p))])
+            else:
+                verbLIST.append([(v.start(), v.end(), v.group(0)) for v in list(verbPat.finditer(p))])
         else:
             verbLIST.append([])
     if not indexWithPOS:
